@@ -2,7 +2,7 @@
 
         XFLR5Application Class
 
-    Copyright (C) 2008 Andre Deperrois XFLR5@yahoo.com
+    Copyright (C) 2008 Andre Deperrois adeperrois@xflr5.com
                        Francesco Meschia francesco.meschia@gmail.com
 
     This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 #define XFLR5APPLICATION_H
 
 #include <QApplication>
-#include "MainFrame.h"
+#include "mainframe.h"
 
 class XFLR5Application : public QApplication
 {
